pub enum TileByteRange {
Chunky(Range<u64>),
Planar(Vec<Range<u64>>),
}Expand description
A description of the byte ranges for a tile, which may differ based on whether the TIFF is in chunky or planar format.
Variants
Chunky(Range<u64>)
For chunky TIFFs, a single byte range for the tile that includes all bands.
Planar(Vec<Range<u64>>)
For planar TIFFs, separate byte ranges for each band of the tile.