pub enum TilesByteRanges {
Chunky(Vec<Range<u64>>),
Planar(Vec<Vec<Range<u64>>>),
}Expand description
A description of the byte ranges for multiple tiles
Variants
Chunky(Vec<Range<u64>>)
For chunky TIFFs, a byte range for each tile that includes all bands.
Planar(Vec<Vec<Range<u64>>>)
For planar TIFFs, separate byte ranges for each band of each tile.